@@ -112,11 +112,9 @@ class SubscriptionDialog::Private
     void readConfig()
     {
       KConfigGroup group( KGlobal::config(), "SubscriptionDialog" );
-      const QSize sizeDialog = group.readEntry( "Size", QSize() );
+      const QSize sizeDialog = group.readEntry( "Size", QSize(300,200) );
       if ( sizeDialog.isValid() ) {
          q->resize( sizeDialog );
-      } else {
-         q->resize( 300,200);
       }
     }
 
@@ -136,7 +134,6 @@ class SubscriptionDialog::Private
 
 };
 
-
 void SubscriptionDialog::Private::slotSubscribe()
 {
 #ifndef KDEPIM_MOBILE_UI
@@ -159,7 +156,6 @@ void SubscriptionDialog::Private::slotUnSubscribe()
 #endif
 }
 
-
 SubscriptionDialog::SubscriptionDialog(QWidget * parent) :
     KDialog( parent ),
     d( new Private( this ) )
@@ -200,7 +196,6 @@ void SubscriptionDialog::init( const QStringList &mimetypes )
     d->filterRecursiveCollectionFilter->addContentMimeTypeInclusionFilters( mimetypes );
   }
 
-
   d->collectionView = new QTreeView( mainWidget );
   d->collectionView->setEditTriggers( QAbstractItemView::NoEditTriggers );
   d->collectionView->header()->hide();
@@ -222,11 +217,9 @@ void SubscriptionDialog::init( const QStringList &mimetypes )
            this, SLOT(slotSetIncludeCheckedOnly(bool)) );
   filterBarLayout->addWidget( checkBox );
 
-
   QHBoxLayout *hboxLayout = new QHBoxLayout;
   hboxLayout->addWidget( d->collectionView );
 
-
   QVBoxLayout *subscribeButtonLayout = new QVBoxLayout;
   d->subscribe = new KPushButton(i18n("Subscribe"));
   subscribeButtonLayout->addWidget(d->subscribe);
@@ -237,13 +230,11 @@ void SubscriptionDialog::init( const QStringList &mimetypes )
   connect(d->unSubscribe,SIGNAL(clicked()),this,SLOT(slotUnSubscribe()));
   subscribeButtonLayout->addItem( new QSpacerItem( 5, 5, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
 
-
   hboxLayout->addLayout(subscribeButtonLayout);
 
   mainLayout->addLayout(filterBarLayout);
   mainLayout->addLayout(hboxLayout);
 
-
 #else
 
   d->filterRecursiveCollectionFilter
@@ -280,5 +271,4 @@ SubscriptionDialog::~SubscriptionDialog()
   delete d;
 }
 
-
 #include "moc_subscriptiondialog_p.cpp"
