@@ -28,11 +28,12 @@ class ItemFetchTest : public QObject
   private slots:
     void initTestCase();
     void testFetch();
+    void testResourceRetrieval();
     void testIllegalFetch();
     void testMultipartFetch_data();
     void testMultipartFetch();
-    void testVirtualFetch();
+    void testRidFetch();
+    void testAncestorRetrieval();
 };
 
-
 #endif
